 /**
 * DaConstants.nc
 * @author Daria Antonova
 */
 typedef struct CntMsg {
   uint16_t src;  // source of message
   uint8_t type;  // DISCOVERY of REPLY packet
   uint8_t seqno; // current epoch
   // hop count in DISCOVERY packet and subtree
   uint8_t subtree_hop_count; // count in REPLY packet
 } CntMsg;

enum {
  BASE_STATION_ID = 0,
  DISCOVERY_PACKET = 1,
  REPLY_PACKET = 2,
  DISCOVERY_EPOCH_GAP = 30000,
  REPLY_GAP = 10000,
  RAND_TIME_INTERVAL = 10,
  BROADCAST_TIME_INTERVAL = 20,
  MAX_NODES = 50,
  MAX_RETRANSMISSIONS = 20,
};

enum {
  AM_CNTMSG = 4
};
